@@ -139,10 +139,17 @@ igt_vpp <- function(data          = "choose",
   
   # Load data
   if (file.exists(data)) {
-    rawdata <- read.table( data, header = T )
+    rawdata <- read.table( data, header = T, sep="\t")
   } else {
     stop("** The data file does not exist. Please check it again. **\n  e.g., data = '/MyFolder/SubFolder/dataFile.txt', ... **\n")
   }  
+  # Remove rows containing NAs
+  NA_rows_all = which(is.na(rawdata), arr.ind = T)  # rows with NAs
+  NA_rows = unique(NA_rows_all[, "row"])
+  if (length(NA_rows) > 0) {
+    rawdata = rawdata[-NA_rows, ]
+    cat("The number of rows with NAs=", length(NA_rows), ". They are removed prior to modeling the data. \n", sep="")
+  }
   
   # Individual Subjects
   subjList <- unique(rawdata[,"subjID"])  # list of subjects x blocks
@@ -166,7 +173,7 @@ igt_vpp <- function(data          = "choose",
   cat(" # of MCMC samples (per chain) = ", niter, "\n")
   cat(" # of burn-in samples          = ", nwarmup, "\n")
   cat(" # of subjects                 = ", numSubjs, "\n")
-  cat(" Payscale                      = ", payscale, "\n")
+  cat(" # Payscale                    = ", payscale, "\n")
   
   ################################################################################
   # THE DATA.  ###################################################################
