@@ -137,10 +137,17 @@ ug_delta <- function(data          = "choose",
   
   # Load data
   if (file.exists(data)) {
-    rawdata <- read.table( data, header = T )
+    rawdata <- read.table( data, header = T, sep="\t")
   } else {
     stop("** The data file does not exist. Please check it again. **\n  e.g., data = '/MyFolder/SubFolder/dataFile.txt', ... **\n")
   }  
+  # Remove rows containing NAs
+  NA_rows_all = which(is.na(rawdata), arr.ind = T)  # rows with NAs
+  NA_rows = unique(NA_rows_all[, "row"])
+  if (length(NA_rows) > 0) {
+    rawdata = rawdata[-NA_rows, ]
+    cat("The number of rows with NAs=", length(NA_rows), ". They are removed prior to modeling the data. \n", sep="")
+  } 
   
   # Individual Subjects
   subjList <- unique(rawdata[,"subjID"])  # list of subjects x blocks
